==> fetch-1.0.3.tgz: package/es/fetch-api-driver.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import isAbsoluteUrl from 'axios/lib/helpers/isAbsoluteURL';
import { isNativeAbortError } from './helpers';
var responseTypes = ['arraybuffer', 'blob', 'formData', 'json', 'text', null];

var getData = function getData(response, responseType) {
  if (responseType === null) {
    return Promise.resolve(null);
  }

  return response[responseType]();
};

var getResponse = function getResponse(response, responseType) {
  if (responseTypes.indexOf(responseType) === -1) {
    throw new Error("responseType must be one of the following: 'arraybuffer', 'blob', 'formData', 'json', 'text', null");
  }

  return getData(response, responseType).then(function (data) {
    return {
      data: data,
      status: response.status,
      headers: response.headers
    };
  });
};

var DummyAbortController = /*#__PURE__*/function () {
  function DummyAbortController() {}

  var _proto = DummyAbortController.prototype;

  /* eslint-disable-next-line class-methods-use-this */
  _proto.abort = function abort() {};

  return DummyAbortController;
}();

export var createDriver = function createDriver(fetchInstance, _temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      _ref$baseURL = _ref.baseURL,
      baseURL = _ref$baseURL === void 0 ? '' : _ref$baseURL,
      _ref$AbortController = _ref.AbortController,
      AbortController = _ref$AbortController === void 0 ? DummyAbortController : _ref$AbortController;

  return function (_ref2) {
    var url = _ref2.url,
        _ref2$responseType = _ref2.responseType,
        responseType = _ref2$responseType === void 0 ? 'json' : _ref2$responseType,
        requestConfig = _objectWithoutPropertiesLoose(_ref2, ["url", "responseType"]);

    var abortSource = new AbortController();
    var responsePromise = fetchInstance(isAbsoluteUrl(url) ? url : baseURL + url, _extends({
      signal: abortSource.signal
    }, requestConfig)).then(function (response) {
      if (response.ok) {
        return getResponse(response, responseType);
      }

      return response.json().then(function (data) {
        response.data = data;
        throw response;
      }, function () {
        throw response;
      });
    })["catch"](function (error) {
      if (isNativeAbortError(error)) {
        throw 'REQUEST_ABORTED';
      }

      throw error;
    });

    responsePromise.cancel = function () {
      return abortSource.abort();
    };

    return responsePromise;
  };
};

==> fetch-1.1.1.tgz: package/es/fetch-api-driver.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import { isNativeAbortError, isAbsoluteURL } from './helpers';
var responseTypes = ['arraybuffer', 'blob', 'formData', 'json', 'text', null];

var getData = function getData(response, responseType) {
  if (responseType === null) {
    return Promise.resolve(null);
  }

  return response[responseType]();
};

var getResponse = function getResponse(response, responseType) {
  if (responseTypes.indexOf(responseType) === -1) {
    throw new Error("responseType must be one of the following: 'arraybuffer', 'blob', 'formData', 'json', 'text', null");
  }

  return getData(response, responseType).then(function (data) {
    return {
      data: data,
      status: response.status,
      headers: response.headers
    };
  });
};

var DummyAbortController = /*#__PURE__*/function () {
  function DummyAbortController() {}

  var _proto = DummyAbortController.prototype;

  /* eslint-disable-next-line class-methods-use-this */
  _proto.abort = function abort() {};

  return DummyAbortController;
}();

export var createDriver = function createDriver(fetchInstance, _temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      _ref$baseURL = _ref.baseURL,
      baseURL = _ref$baseURL === void 0 ? '' : _ref$baseURL,
      _ref$AbortController = _ref.AbortController,
      AbortController = _ref$AbortController === void 0 ? DummyAbortController : _ref$AbortController;

  return function (_ref2) {
    var url = _ref2.url,
        _ref2$responseType = _ref2.responseType,
        responseType = _ref2$responseType === void 0 ? 'json' : _ref2$responseType,
        requestConfig = _objectWithoutPropertiesLoose(_ref2, ["url", "responseType"]);

    var abortSource = new AbortController();
    var responsePromise = fetchInstance(isAbsoluteURL(url) ? url : baseURL + url, _extends({
      signal: abortSource.signal
    }, requestConfig)).then(function (response) {
      if (response.ok) {
        return getResponse(response, responseType);
      }

      return response.json().then(function (data) {
        response.data = data;
        throw response;
      }, function () {
        throw response;
      });
    })["catch"](function (error) {
      if (isNativeAbortError(error)) {
        throw 'REQUEST_ABORTED';
      }

      throw error;
    });

    responsePromise.cancel = function () {
      return abortSource.abort();
    };

    return responsePromise;
  };
};
